@@ -41,11 +41,7 @@ class Settings(BaseSettings):
         default=None,
         description="The alias of the model to use for generating completions.",
     )
-    seed: int = Field(default=llama_cpp.LLAMA_DEFAULT_SEED, description="Random seed. -1 for random.")
-    n_ctx: int = Field(default=2048, ge=1, description="The context size.")
-    n_batch: int = Field(
-        default=512, ge=1, description="The batch size to use per eval."
-    )
+    # Model Params
     n_gpu_layers: int = Field(
         default=0,
         ge=-1,
@@ -60,17 +56,6 @@ class Settings(BaseSettings):
         default=None,
         description="Split layers across multiple GPUs in proportion.",
     )
-    rope_freq_base: float = Field(
-        default=0.0, description="RoPE base frequency"
-    )
-    rope_freq_scale: float = Field(
-        default=0.0, description="RoPE frequency scaling factor"
-    )
-    mul_mat_q: bool = Field(
-        default=True, description="if true, use experimental mul_mat_q kernels"
-    )
-    f16_kv: bool = Field(default=True, description="Whether to use f16 key/value.")
-    logits_all: bool = Field(default=True, description="Whether to return logits.")
     vocab_only: bool = Field(
         default=False, description="Whether to only return the vocabulary."
     )
@@ -82,17 +67,59 @@ class Settings(BaseSettings):
         default=llama_cpp.llama_mlock_supported(),
         description="Use mlock.",
     )
-    embedding: bool = Field(default=True, description="Whether to use embeddings.")
+    # Context Params
+    seed: int = Field(default=llama_cpp.LLAMA_DEFAULT_SEED, description="Random seed. -1 for random.")
+    n_ctx: int = Field(default=2048, ge=1, description="The context size.")
+    n_batch: int = Field(
+        default=512, ge=1, description="The batch size to use per eval."
+    )
     n_threads: int = Field(
         default=max(multiprocessing.cpu_count() // 2, 1),
         ge=1,
         description="The number of threads to use.",
     )
+    n_threads_batch: int = Field(
+        default=max(multiprocessing.cpu_count() // 2, 1),
+        ge=0,
+        description="The number of threads to use when batch processing.",
+    )
+    rope_scaling_type: int = Field(
+        default=llama_cpp.LLAMA_ROPE_SCALING_UNSPECIFIED
+    )
+    rope_freq_base: float = Field(
+        default=0.0, description="RoPE base frequency"
+    )
+    rope_freq_scale: float = Field(
+        default=0.0, description="RoPE frequency scaling factor"
+    )
+    yarn_ext_factor: float = Field(
+        default=float("nan")
+    )
+    yarn_attn_factor: float = Field(
+        default=1.0
+    )
+    yarn_beta_fast: float = Field(
+        default=32.0
+    )
+    yarn_beta_slow: float = Field(
+        default=1.0
+    )
+    yarn_orig_ctx: int = Field(
+        default=0
+    )
+    mul_mat_q: bool = Field(
+        default=True, description="if true, use experimental mul_mat_q kernels"
+    )
+    f16_kv: bool = Field(default=True, description="Whether to use f16 key/value.")
+    logits_all: bool = Field(default=True, description="Whether to return logits.")
+    embedding: bool = Field(default=True, description="Whether to use embeddings.")
+    # Sampling Params
     last_n_tokens_size: int = Field(
         default=64,
         ge=0,
         description="Last n tokens to keep for repeat penalty calculation.",
     )
+    # LoRA Params
     lora_base: Optional[str] = Field(
         default=None,
         description="Optional path to base model, useful if using a quantized base model and you want to apply LoRA to an f16 model."
@@ -101,14 +128,17 @@ class Settings(BaseSettings):
         default=None,
         description="Path to a LoRA file to apply to the model.",
     )
+    # Backend Params
     numa: bool = Field(
         default=False,
         description="Enable NUMA support.",
     )
+    # Chat Format Params
     chat_format: str = Field(
         default="llama-2",
         description="Chat format to use.",
     )
+    # Cache Params
     cache: bool = Field(
         default=False,
         description="Use a cache to reduce processing times for evaluated prompts.",
@@ -121,9 +151,11 @@ class Settings(BaseSettings):
         default=2 << 30,
         description="The size of the cache in bytes. Only used if cache is True.",
     )
+    # Misc
     verbose: bool = Field(
         default=True, description="Whether to print debug information."
     )
+    # Server Params
     host: str = Field(default="localhost", description="Listen address")
     port: int = Field(default=8000, description="Listen port")
     interrupt_requests: bool = Field(
@@ -345,27 +377,41 @@ def create_app(settings: Optional[Settings] = None):
     global llama
     llama = llama_cpp.Llama(
         model_path=settings.model,
-        seed=settings.seed,
-        n_ctx=settings.n_ctx,
-        n_batch=settings.n_batch,
+        # Model Params
         n_gpu_layers=settings.n_gpu_layers,
         main_gpu=settings.main_gpu,
         tensor_split=settings.tensor_split,
-        rope_freq_base=settings.rope_freq_base,
-        rope_freq_scale=settings.rope_freq_scale,
-        mul_mat_q=settings.mul_mat_q,
-        f16_kv=settings.f16_kv,
-        logits_all=settings.logits_all,
         vocab_only=settings.vocab_only,
         use_mmap=settings.use_mmap,
         use_mlock=settings.use_mlock,
-        embedding=settings.embedding,
+        # Context Params
+        seed=settings.seed,
+        n_ctx=settings.n_ctx,
+        n_batch=settings.n_batch,
         n_threads=settings.n_threads,
+        n_threads_batch=settings.n_threads_batch,
+        rope_scaling_type=settings.rope_scaling_type,
+        rope_freq_base=settings.rope_freq_base,
+        rope_freq_scale=settings.rope_freq_scale,
+        yarn_ext_factor=settings.yarn_ext_factor,
+        yarn_attn_factor=settings.yarn_attn_factor,
+        yarn_beta_fast=settings.yarn_beta_fast,
+        yarn_beta_slow=settings.yarn_beta_slow,
+        yarn_orig_ctx=settings.yarn_orig_ctx,
+        mul_mat_q=settings.mul_mat_q,
+        f16_kv=settings.f16_kv,
+        logits_all=settings.logits_all,
+        embedding=settings.embedding,
+        # Sampling Params
         last_n_tokens_size=settings.last_n_tokens_size,
+        # LoRA Params
         lora_base=settings.lora_base,
         lora_path=settings.lora_path,
+        # Backend Params
         numa=settings.numa,
+        # Chat Format Params
         chat_format=settings.chat_format,
+        # Misc
         verbose=settings.verbose,
     )
     if settings.cache:
@@ -594,7 +640,7 @@ def make_logit_bias_processor(
     elif logit_bias_type == "tokens":
         for token, score in logit_bias.items():
             token = token.encode("utf-8")
-            for input_id in llama.tokenize(token, add_bos=False):
+            for input_id in llama.tokenize(token, add_bos=False, special=True):
                 to_bias[input_id] = score
 
     def logit_bias_processor(
